# Ansible role for Upstream source tarball tests

Put this role in your tests.yml playbook. The playbook
will extract the upstream source tarball as described in
the package spec file into a test/source/ directory. You
can then use or execute files (usually tests) from the
upstream sources in your playbook.

The whole playbook directory including tarball(s), patches and the spec file will be available on {{ tenv_workdir }}.

You can redefine the following variables:

 * srcdir: A directory to extract sources into. This defaults
   to {{ playbook_dir }}/source/
   This variable is ignored if fetch_only is True.
 * flatten: Strip one level of path prefix in source tree. This
   defaults to True
   This variable is ignored if fetch_only is True.
 * fetch_only: If True the role will fetch the source, copy files including source to test environment under {{ tenv_workdir }} and it will skip rpmbuild --bp part.
   Set to True if spec file %prep section requires packages that are not available on test runner.
   This defaults to False

Example usage:

    ---
    - hosts: localhost
      tags:
      - classic
      roles:
      - role: standard-test-source

      - role: standard-test-basic
        required_packages:
        - make
        tests:
        - smoke:
            dir: ./source
            run: make check


Example usage with fetch_only = True:

    ---
    - hosts: localhost
      tags:
      - classic
      pre_tasks:
      - import_role:
          name: standard-test-source
        vars:
          fetch_only: True

      roles:
      - role: standard-test-basic
        required_packages:
        - autoconf
        - automake
        - make
        - rpm-build
        tests:
        - prepare-source:
            # basic role uses the path from dir parameter as relative to test directory, therefore dir: "{{tenv_workdir}}" doesn't work
            dir: ./
            run: "rpmbuild -bp {{tenv_workdir}}/*.spec --nodeps --define '_sourcedir {{tenv_workdir}}' --define '_builddir {{tenv_workdir}}/source'"
        - flatten-source:
            dir: ./
            run: "shopt -s dotglob; mv {{tenv_workdir}}/source/*/* {{tenv_workdir}}/source"
        - smoke:
            dir: ./source
            run: "make check"
